@@ -5,8 +5,6 @@ import logging
 from mopidy.backends import base, listener
 from mopidy.models import Playlist
 
-from . import translator
-
 logger = logging.getLogger('mopidy.backends.gmusic')
 
 
@@ -26,14 +24,17 @@ class GMusicPlaylistsProvider(base.BasePlaylistsProvider):
     def refresh(self):
         playlists = []
 
-        for subdir, entry in self.backend.session.get_all_playlist_ids().items():
-            for name, ids in entry.items():
-                for i in ids:
-                    tracks = [translator.to_mopidy_track(track) for track in 
-                              self.backend.session.get_playlist_songs(i)]
-                  
-                    playlist = Playlist(uri='gmusic:' + i, name=name, tracks=tracks)
-                    playlists.append(playlist)
+        for playlist in self.backend.session.get_all_playlist_contents():
+            tracks = []
+            for track in playlist['tracks']:
+                if not track['deleted']:
+                    tracks += self.backend.library.lookup('gmusic:track:' +
+                                                          track['trackId'])
+
+            playlist = Playlist(uri='gmusic:playlist:' + playlist['id'],
+                                name=playlist['name'],
+                                tracks=tracks)
+            playlists.append(playlist)
 
         self.playlists = playlists
         listener.BackendListener.send('playlists_loaded')
